@@ -32,7 +32,6 @@ from variety.Options import Options
 from variety.AddFlickrDialog import AddFlickrDialog
 from variety.AddMediaRssDialog import AddMediaRssDialog
 from variety.AddRedditDialog import AddRedditDialog
-from variety.AddPanoramioDialog import AddPanoramioDialog
 from variety.EditFavoriteOperationsDialog import EditFavoriteOperationsDialog
 from variety.SmartFeaturesConfirmationDialog import SmartFeaturesConfirmationDialog
 from variety.LoginOrRegisterDialog import LoginOrRegisterDialog
@@ -64,7 +63,6 @@ UNREMOVEABLE_TYPES = [
 EDITABLE_TYPES = [
     Options.SourceType.FLICKR,
     Options.SourceType.MEDIA_RSS,
-    Options.SourceType.PANORAMIO,
     Options.SourceType.WALLHAVEN,
     Options.SourceType.REDDIT,
 ]
@@ -357,7 +355,7 @@ class PreferencesVarietyDialog(PreferencesDialog):
             timer.start()
 
     def on_add_button_clicked(self, widget=None):
-        def position(x, y):
+        def position(menu, x, y, icon):
             button_alloc = self.ui.add_button.get_allocation()
             window_pos = self.ui.add_button.get_window().get_position()
             return button_alloc.x + window_pos[0], button_alloc.y + button_alloc.height + window_pos[1], True
@@ -365,7 +363,7 @@ class PreferencesVarietyDialog(PreferencesDialog):
         self.add_menu.popup(None, self.ui.add_button, position, None, 0, Gtk.get_current_event_time())
 
     def on_remove_sources_clicked(self, widget=None):
-        def position(x, y):
+        def position(menu, x, y, icon):
             button_alloc = self.ui.remove_sources.get_allocation()
             window_pos = self.ui.remove_sources.get_window().get_position()
             return button_alloc.x + window_pos[0], button_alloc.y + button_alloc.height + window_pos[1], True
@@ -381,7 +379,6 @@ class PreferencesVarietyDialog(PreferencesDialog):
             '-',
             (_("Flickr"), self.on_add_flickr_clicked),
             (_("Wallhaven.cc"), self.on_add_wallhaven_clicked),
-            (_("Panoramio"), self.on_add_panoramio_clicked),
             (_("Reddit"), self.on_add_reddit_clicked),
             (_("Media RSS"), self.on_add_mediarss_clicked),
         ]
@@ -672,8 +669,6 @@ class PreferencesVarietyDialog(PreferencesDialog):
                 self.dialog = AddRedditDialog()
             elif type == Options.SourceType.MEDIA_RSS:
                 self.dialog = AddMediaRssDialog()
-            elif type == Options.SourceType.PANORAMIO:
-                self.dialog = AddPanoramioDialog()
 
             self.dialog.set_edited_row(edited_row)
             self.show_dialog(self.dialog)
@@ -786,9 +781,6 @@ class PreferencesVarietyDialog(PreferencesDialog):
     def on_add_wallhaven_clicked(self, widget=None):
         self.show_dialog(AddWallhavenDialog())
 
-    def on_add_panoramio_clicked(self, widget=None):
-        self.show_dialog(AddPanoramioDialog())
-
     def show_dialog(self, dialog):
         self.dialog = dialog
         self.dialog.parent = self
