@@ -28,7 +28,11 @@ import threading
 import time
 import pyexiv2
 import urllib
+import functools
+import datetime
 from urlparse import urlparse
+from PIL import Image
+
 from DominantColors import DominantColors
 from gi.repository import Gdk, Pango, GdkPixbuf, GLib
 import inspect
@@ -37,9 +41,9 @@ import platform
 from variety import _u, _str
 
 
-VARIETY_INFO = "Downloaded by Variety wallpaper changer, http://peterlevi.com/variety"
+VARIETY_INFO = "-"
 
-USER_AGENT = "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.22 (KHTML, like Gecko) Ubuntu/12.04 Chromium/25.0.1364.172 Chrome/25.0.1364.172 Safari/537.22"
+USER_AGENT = "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/53.0.2785.143 Safari/537.36"
 
 SOURCE_NAME_TO_TYPE = {
     'wallbase.cc': 'wallbase',
@@ -136,6 +140,33 @@ class throttle(object):
         return wrapper
 
 
+def cache(ttl_seconds=100*365*24*3600, debug=False):
+    """
+    caching decorator with TTL. Keep in mind the cache is per-process.
+    TODO: There is no process for cache invalidation now. Introduce memcached and use it instead.
+    :param ttl_seconds: TTL in seconds before the cache entry expires
+    :param debug: use True to log cache hits (with DEBUG level)
+    """
+    def decorate(f):
+        _cache = {}
+
+        @functools.wraps(f)
+        def decorated(*args):
+            cached = _cache.get(args)
+            if not cached or cached['timestamp'] < datetime.datetime.now() - datetime.timedelta(seconds=ttl_seconds):
+                cached = {
+                    'timestamp': datetime.datetime.now(),
+                    'result': f(*args)
+                }
+                _cache[args] = cached
+            elif debug:
+                logger.debug(lambda: '@cache hit for %s' % str(args))
+            return cached['result']
+        return decorated
+
+    return decorate
+
+
 class Util:
     @staticmethod
     def log_all(cls, level=logging.DEBUG):
@@ -190,12 +221,28 @@ class Util:
 
     @staticmethod
     def is_image(filename, check_contents=False):
+        if Util.is_animated_gif(filename):
+            return False
+
         if not check_contents:
             return filename.lower().endswith(('.jpg', '.jpeg', '.gif', '.png', '.tiff', '.svg', '.bmp'))
         else:
             format, image_width, image_height = GdkPixbuf.Pixbuf.get_file_info(filename)
             return bool(format)
 
+    @staticmethod
+    def is_animated_gif(filename):
+        if not filename.lower().endswith('.gif'):
+            return False
+
+        gif = Image.open(filename)
+        try:
+            gif.seek(1)
+        except EOFError:
+            return False
+        else:
+            return True
+
     @staticmethod
     def list_files(files=(), folders=(), filter_func=(lambda f: True), max_files=10000, randomize=True):
         count = 0
@@ -235,6 +282,34 @@ class Util:
         force_exit_thread.daemon = True
         force_exit_thread.start()
 
+    @staticmethod
+    def check_and_update_metadata(filename):
+        try:
+            pyexiv2.xmp.register_namespace("https://launchpad.net/variety/", "variety")
+        except KeyError:
+            pass
+
+        try:
+            m = pyexiv2.ImageMetadata(filename)
+            m.read()
+        except Exception:
+            logger.exception(lambda: "Could not read metadata for %s" % filename)
+            return False
+
+        try:
+            if 'Xmp.variety.info' in m or 'vrty.org' in m.get('imageURL', ''):
+                logger.info(lambda: 'Updating metadata for %s' % filename)
+                del m["Xmp.variety.info"]
+                if 'imageURL' in m and 'vrty.org' in m['imageURL']:
+                    del m['imageURL']
+                m.write(preserve_timestamps=True)
+
+                return True
+        except Exception:
+            logger.exception(lambda: "Could not read metadata for %s" % filename)
+
+        return False
+
     @staticmethod
     def write_metadata(filename, info):
         try:
@@ -245,7 +320,6 @@ class Util:
         try:
             m = pyexiv2.ImageMetadata(filename)
             m.read()
-            m["Xmp.variety.info"] = VARIETY_INFO
             for k, v in info.items():
                 if k == 'author':
                     m["Xmp.variety." + k] = v
@@ -432,7 +506,8 @@ class Util:
                                  data=data,
                                  headers=headers,
                                  stream=stream,
-                                 allow_redirects=True)
+                                 allow_redirects=True,
+                                 verify=False)
             r.raise_for_status()
             return r
         except requests.exceptions.SSLError:
