@@ -316,8 +316,8 @@ class Indicator:
         self.status_icon = None
         self.visible = True
 
-        def pos(menu, icon):
-            return Gtk.StatusIcon.position_menu(self.menu, icon)
+        def pos(menu, x, y, icon):
+            return Gtk.StatusIcon.position_menu(self.menu, x, y, icon)
 
         def right_click_event(icon, button, time):
             self.menu.popup(None, None, pos, self.status_icon, 0, time)
